import * as cdk from 'aws-cdk-lib';
import * as ec2 from 'aws-cdk-lib/aws-ec2';
import { Construct } from 'constructs';
import { DagsOptions, ConfigsOptions } from './dag-storage';
import { Sizing } from './sizing';
/**
 * Interface defining the properties for configuring MWAA (Managed Airflow).
 */
export interface MWAAProps {
    /**
     * The name of the Airflow environment.
     */
    readonly environmentName: string;
    /**
     * The version of Airflow to deploy.
     */
    readonly airflowVersion: string;
    /**
     * Optional sizing configuration for the MWAA environment.
     * Defines the compute resources.
     */
    readonly sizing?: Sizing;
    /**
     * The VPC in which to deploy the MWAA environment.
     * If not provided, a default VPC will be created.
     */
    readonly vpc?: ec2.IVpc;
    /**
     * The name of the S3 bucket used for storing DAGs.
     * If not provided, a default bucket is created.
     */
    readonly bucketName?: string;
    /** Configuration for DAG storage. */
    readonly dagsOptions?: DagsOptions;
    /** Configuration for plugins storage. */
    readonly configsOptions?: ConfigsOptions;
    /**
     * Airflow configuration options as key-value pairs.
     * These configuration options are passed to the Airflow environment.
     */
    readonly airflowConfigurationOptions?: {
        [key: string]: any;
    };
    /**
     * The removal policy for the MWAA resources.
     * Determines what happens to the resources when they are deleted.
     * Defaults to 'RETAIN' if not specified.
     */
    readonly removalPolicy?: cdk.RemovalPolicy;
}
/**
 * PublicRoutingMWAA constructs a Managed Airflow (MWAA) environment with public webserver access.
 * It creates the necessary VPC, S3 storage for DAGs, and an Airflow environment.
 */
export declare class PublicRoutingMWAA extends Construct {
    constructor(scope: Construct, id: string, props: MWAAProps);
}
